@@ -1,22 +1,23 @@
 /*
- *      Copyright (C) 2004 Simon Josefsson
+ *      Copyright (C) 2004, 2006 Free Software Foundation, Inc.
  *      Copyright (C) 2002 Fabio Fiorina
  *
- * This file is part of LIBASN1.
+ * This file is part of LIBTASN1.
  *
- * GNUTLS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * The LIBTASN1 library is free software; you can redistribute it
+ * and/or modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * GNUTLS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA
  */
 
 #ifndef INT_H
@@ -34,15 +35,9 @@
 
 #include <mem.h>
 
-#define MAX32 4294967295
-#define MAX24 16777215
-#define MAX16 65535
-
 #define MAX_LOG_SIZE 1024 /* maximum number of characters of a log message */
-#define MAX_NAME_SIZE 128 /* maximum number of characters of a name inside an ASN1 file definiton */
-#define MAX_ERROR_DESCRIPTION_SIZE 128 /* maximum number of characters of a description message */
 
-/* define used for visiting trees */
+/* Define used for visiting trees. */
 #define UP     1
 #define RIGHT  2
 #define DOWN   3
